@@ -29,15 +29,19 @@ from AnyQt.QtWidgets import (
     QVBoxLayout, QLabel
 )
 
-import Orange.data
-
+from Orange.data import Table
 from Orange.widgets import widget, gui, settings
 from Orange.widgets.utils.filedialogs import RecentPath
 from Orange.widgets.utils.concurrent import (
     ThreadExecutor, FutureWatcher, methodinvoke
 )
 
-from Orange.canvas.preview.previewbrowser import TextLabel
+try:
+    from orangecanvas.preview.previewbrowser import TextLabel
+except ImportError:
+    from Orange.canvas.preview.previewbrowser import TextLabel
+
+from Orange.widgets.utils.signals import Output
 
 from orangecontrib.imageanalytics.import_images import ImportImages
 
@@ -100,7 +104,8 @@ class OWImportImages(widget.OWWidget):
     icon = "icons/ImportImages.svg"
     priority = 110
 
-    outputs = [("Data", Orange.data.Table)]
+    class Outputs:
+        data = Output('Data', Table, default=True)
 
     #: list of recent paths
     recent_paths = settings.Setting([])  # type: List[RecentPath]
@@ -340,7 +345,7 @@ class OWImportImages(widget.OWWidget):
         """
         if self.recent_paths and path is not None and \
                 os.path.isdir(self.recent_paths[0].abspath) and os.path.isdir(path) \
-                and os.path.samefile(os.path.isdir(self.recent_paths[0].abspath), path):
+                and os.path.samefile(self.recent_paths[0].abspath, path):
             return True
 
         success = True
@@ -577,7 +582,7 @@ class OWImportImages(widget.OWWidget):
         """
         Commit a Table from the collected image meta data.
         """
-        self.send("Data", self.data)
+        self.Outputs.data.send(self.data)
 
     def onDeleteWidget(self):
         self.cancel()
